"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsNewDynamicAnalyzerScan:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "scan_type": "str",
        "presence_id": "str",
        "include_verified_domains": "bool",
        "recurrence_rule": "str",
        "recurrence_start_date": "datetime",
        "recurrence_end_date": "datetime",
        "starting_url": "str",
        "login_user": "str",
        "login_password": "str",
        "extra_field": "str",
        "http_auth_user_name": "str",
        "http_auth_password": "str",
        "http_auth_domain": "str",
        "otp_secret_key": "str",
        "otp_length": "int",
        "otp_hash_type": "str",
        "otp_time_step": "int",
        "otp_http_parameters": "str",
        "thread_num": "int",
        "connection_timeout": "int",
        "test_policy": "str",
        "test_optimization_level": "str",
        "use_automatic_timeout": "bool",
        "max_requests_in": "int",
        "max_requests_time_frame": "int",
        "should_scan_below_this_directory": "bool",
        "allowed_domains": "list[str]",
        "use_case_sensitive_paths": "bool",
        "only_full_results": "bool",
        "login_sequence_file_id": "str",
        "fully_automatic": "bool",
        "scan_name": "str",
        "enable_mail_notification": "bool",
        "locale": "str",
        "app_id": "str",
        "execute": "bool",
        "personal": "bool",
        "comment": "str",
    }

    attribute_map = {
        "scan_type": "ScanType",
        "presence_id": "PresenceId",
        "include_verified_domains": "IncludeVerifiedDomains",
        "recurrence_rule": "RecurrenceRule",
        "recurrence_start_date": "RecurrenceStartDate",
        "recurrence_end_date": "RecurrenceEndDate",
        "starting_url": "StartingUrl",
        "login_user": "LoginUser",
        "login_password": "LoginPassword",
        "extra_field": "ExtraField",
        "http_auth_user_name": "HttpAuthUserName",
        "http_auth_password": "HttpAuthPassword",
        "http_auth_domain": "HttpAuthDomain",
        "otp_secret_key": "OtpSecretKey",
        "otp_length": "OtpLength",
        "otp_hash_type": "OtpHashType",
        "otp_time_step": "OtpTimeStep",
        "otp_http_parameters": "OtpHttpParameters",
        "thread_num": "ThreadNum",
        "connection_timeout": "ConnectionTimeout",
        "test_policy": "TestPolicy",
        "test_optimization_level": "TestOptimizationLevel",
        "use_automatic_timeout": "UseAutomaticTimeout",
        "max_requests_in": "MaxRequestsIn",
        "max_requests_time_frame": "MaxRequestsTimeFrame",
        "should_scan_below_this_directory": "ShouldScanBelowThisDirectory",
        "allowed_domains": "AllowedDomains",
        "use_case_sensitive_paths": "UseCaseSensitivePaths",
        "only_full_results": "OnlyFullResults",
        "login_sequence_file_id": "LoginSequenceFileId",
        "fully_automatic": "FullyAutomatic",
        "scan_name": "ScanName",
        "enable_mail_notification": "EnableMailNotification",
        "locale": "Locale",
        "app_id": "AppId",
        "execute": "Execute",
        "personal": "Personal",
        "comment": "Comment",
    }

    def __init__(
        self,
        scan_type=None,
        presence_id=None,
        include_verified_domains=None,
        recurrence_rule=None,
        recurrence_start_date=None,
        recurrence_end_date=None,
        starting_url=None,
        login_user=None,
        login_password=None,
        extra_field=None,
        http_auth_user_name=None,
        http_auth_password=None,
        http_auth_domain=None,
        otp_secret_key=None,
        otp_length=None,
        otp_hash_type=None,
        otp_time_step=None,
        otp_http_parameters=None,
        thread_num=None,
        connection_timeout=None,
        test_policy=None,
        test_optimization_level=None,
        use_automatic_timeout=None,
        max_requests_in=None,
        max_requests_time_frame=None,
        should_scan_below_this_directory=None,
        allowed_domains=None,
        use_case_sensitive_paths=None,
        only_full_results=None,
        login_sequence_file_id=None,
        fully_automatic=None,
        scan_name=None,
        enable_mail_notification=None,
        locale=None,
        app_id=None,
        execute=None,
        personal=None,
        comment=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsNewDynamicAnalyzerScan - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._scan_type = None
        self._presence_id = None
        self._include_verified_domains = None
        self._recurrence_rule = None
        self._recurrence_start_date = None
        self._recurrence_end_date = None
        self._starting_url = None
        self._login_user = None
        self._login_password = None
        self._extra_field = None
        self._http_auth_user_name = None
        self._http_auth_password = None
        self._http_auth_domain = None
        self._otp_secret_key = None
        self._otp_length = None
        self._otp_hash_type = None
        self._otp_time_step = None
        self._otp_http_parameters = None
        self._thread_num = None
        self._connection_timeout = None
        self._test_policy = None
        self._test_optimization_level = None
        self._use_automatic_timeout = None
        self._max_requests_in = None
        self._max_requests_time_frame = None
        self._should_scan_below_this_directory = None
        self._allowed_domains = None
        self._use_case_sensitive_paths = None
        self._only_full_results = None
        self._login_sequence_file_id = None
        self._fully_automatic = None
        self._scan_name = None
        self._enable_mail_notification = None
        self._locale = None
        self._app_id = None
        self._execute = None
        self._personal = None
        self._comment = None
        self.discriminator = None

        if scan_type is not None:
            self.scan_type = scan_type
        if presence_id is not None:
            self.presence_id = presence_id
        if include_verified_domains is not None:
            self.include_verified_domains = include_verified_domains
        if recurrence_rule is not None:
            self.recurrence_rule = recurrence_rule
        if recurrence_start_date is not None:
            self.recurrence_start_date = recurrence_start_date
        if recurrence_end_date is not None:
            self.recurrence_end_date = recurrence_end_date
        if starting_url is not None:
            self.starting_url = starting_url
        if login_user is not None:
            self.login_user = login_user
        if login_password is not None:
            self.login_password = login_password
        if extra_field is not None:
            self.extra_field = extra_field
        if http_auth_user_name is not None:
            self.http_auth_user_name = http_auth_user_name
        if http_auth_password is not None:
            self.http_auth_password = http_auth_password
        if http_auth_domain is not None:
            self.http_auth_domain = http_auth_domain
        if otp_secret_key is not None:
            self.otp_secret_key = otp_secret_key
        if otp_length is not None:
            self.otp_length = otp_length
        if otp_hash_type is not None:
            self.otp_hash_type = otp_hash_type
        if otp_time_step is not None:
            self.otp_time_step = otp_time_step
        if otp_http_parameters is not None:
            self.otp_http_parameters = otp_http_parameters
        if thread_num is not None:
            self.thread_num = thread_num
        if connection_timeout is not None:
            self.connection_timeout = connection_timeout
        if test_policy is not None:
            self.test_policy = test_policy
        if test_optimization_level is not None:
            self.test_optimization_level = test_optimization_level
        if use_automatic_timeout is not None:
            self.use_automatic_timeout = use_automatic_timeout
        if max_requests_in is not None:
            self.max_requests_in = max_requests_in
        if max_requests_time_frame is not None:
            self.max_requests_time_frame = max_requests_time_frame
        if should_scan_below_this_directory is not None:
            self.should_scan_below_this_directory = should_scan_below_this_directory
        if allowed_domains is not None:
            self.allowed_domains = allowed_domains
        if use_case_sensitive_paths is not None:
            self.use_case_sensitive_paths = use_case_sensitive_paths
        if only_full_results is not None:
            self.only_full_results = only_full_results
        if login_sequence_file_id is not None:
            self.login_sequence_file_id = login_sequence_file_id
        if fully_automatic is not None:
            self.fully_automatic = fully_automatic
        self.scan_name = scan_name
        if enable_mail_notification is not None:
            self.enable_mail_notification = enable_mail_notification
        if locale is not None:
            self.locale = locale
        self.app_id = app_id
        if execute is not None:
            self.execute = execute
        if personal is not None:
            self.personal = personal
        if comment is not None:
            self.comment = comment

    @property
    def scan_type(self):
        # type: () -> str
        """Gets the scan_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The scan_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._scan_type

    @scan_type.setter
    def scan_type(self, scan_type):
        """Sets the scan_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param scan_type: The scan_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        allowed_values = ["Staging", "Production", "Custom"]
        if self._configuration.client_side_validation and scan_type not in allowed_values:
            raise ValueError(
                "Invalid value for `scan_type` ({}), must be one of {}".format(
                    scan_type, allowed_values
                )
            )

        self._scan_type = scan_type

    @property
    def presence_id(self):
        # type: () -> str
        """Gets the presence_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The presence_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._presence_id

    @presence_id.setter
    def presence_id(self, presence_id):
        """Sets the presence_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param presence_id: The presence_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """

        self._presence_id = presence_id

    @property
    def include_verified_domains(self):
        # type: () -> bool
        """Gets the include_verified_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The include_verified_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._include_verified_domains

    @include_verified_domains.setter
    def include_verified_domains(self, include_verified_domains):
        """Sets the include_verified_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param include_verified_domains: The include_verified_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._include_verified_domains = include_verified_domains

    @property
    def recurrence_rule(self):
        # type: () -> str
        """Gets the recurrence_rule of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The recurrence_rule of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._recurrence_rule

    @recurrence_rule.setter
    def recurrence_rule(self, recurrence_rule):
        """Sets the recurrence_rule of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param recurrence_rule: The recurrence_rule of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """

        self._recurrence_rule = recurrence_rule

    @property
    def recurrence_start_date(self):
        # type: () -> datetime
        """Gets the recurrence_start_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The recurrence_start_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: datetime
        """
        return self._recurrence_start_date

    @recurrence_start_date.setter
    def recurrence_start_date(self, recurrence_start_date):
        """Sets the recurrence_start_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param recurrence_start_date: The recurrence_start_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: datetime
        """

        self._recurrence_start_date = recurrence_start_date

    @property
    def recurrence_end_date(self):
        # type: () -> datetime
        """Gets the recurrence_end_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The recurrence_end_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: datetime
        """
        return self._recurrence_end_date

    @recurrence_end_date.setter
    def recurrence_end_date(self, recurrence_end_date):
        """Sets the recurrence_end_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param recurrence_end_date: The recurrence_end_date of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: datetime
        """

        self._recurrence_end_date = recurrence_end_date

    @property
    def starting_url(self):
        # type: () -> str
        """Gets the starting_url of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The starting_url of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._starting_url

    @starting_url.setter
    def starting_url(self, starting_url):
        """Sets the starting_url of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param starting_url: The starting_url of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and starting_url is not None
            and len(starting_url) > 2000
        ):
            raise ValueError(
                "Invalid value for `starting_url`, length must be less than or equal to `2000`"
            )
        if (
            self._configuration.client_side_validation
            and starting_url is not None
            and len(starting_url) < 0
        ):
            raise ValueError(
                "Invalid value for `starting_url`, length must be greater than or equal to `0`"
            )

        self._starting_url = starting_url

    @property
    def login_user(self):
        # type: () -> str
        """Gets the login_user of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The login_user of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._login_user

    @login_user.setter
    def login_user(self, login_user):
        """Sets the login_user of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param login_user: The login_user of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and login_user is not None
            and len(login_user) > 1024
        ):
            raise ValueError(
                "Invalid value for `login_user`, length must be less than or equal to `1024`"
            )
        if (
            self._configuration.client_side_validation
            and login_user is not None
            and len(login_user) < 0
        ):
            raise ValueError(
                "Invalid value for `login_user`, length must be greater than or equal to `0`"
            )

        self._login_user = login_user

    @property
    def login_password(self):
        # type: () -> str
        """Gets the login_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The login_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._login_password

    @login_password.setter
    def login_password(self, login_password):
        """Sets the login_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param login_password: The login_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and login_password is not None
            and len(login_password) > 1024
        ):
            raise ValueError(
                "Invalid value for `login_password`, length must be less than or equal to `1024`"
            )
        if (
            self._configuration.client_side_validation
            and login_password is not None
            and len(login_password) < 0
        ):
            raise ValueError(
                "Invalid value for `login_password`, length must be greater than or equal to `0`"
            )

        self._login_password = login_password

    @property
    def extra_field(self):
        # type: () -> str
        """Gets the extra_field of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The extra_field of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._extra_field

    @extra_field.setter
    def extra_field(self, extra_field):
        """Sets the extra_field of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param extra_field: The extra_field of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and extra_field is not None
            and len(extra_field) > 1024
        ):
            raise ValueError(
                "Invalid value for `extra_field`, length must be less than or equal to `1024`"
            )
        if (
            self._configuration.client_side_validation
            and extra_field is not None
            and len(extra_field) < 0
        ):
            raise ValueError(
                "Invalid value for `extra_field`, length must be greater than or equal to `0`"
            )

        self._extra_field = extra_field

    @property
    def http_auth_user_name(self):
        # type: () -> str
        """Gets the http_auth_user_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The http_auth_user_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._http_auth_user_name

    @http_auth_user_name.setter
    def http_auth_user_name(self, http_auth_user_name):
        """Sets the http_auth_user_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param http_auth_user_name: The http_auth_user_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and http_auth_user_name is not None
            and len(http_auth_user_name) > 128
        ):
            raise ValueError(
                "Invalid value for `http_auth_user_name`, length must be less than or equal to `128`"
            )
        if (
            self._configuration.client_side_validation
            and http_auth_user_name is not None
            and len(http_auth_user_name) < 0
        ):
            raise ValueError(
                "Invalid value for `http_auth_user_name`, length must be greater than or equal to `0`"
            )

        self._http_auth_user_name = http_auth_user_name

    @property
    def http_auth_password(self):
        # type: () -> str
        """Gets the http_auth_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The http_auth_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._http_auth_password

    @http_auth_password.setter
    def http_auth_password(self, http_auth_password):
        """Sets the http_auth_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param http_auth_password: The http_auth_password of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and http_auth_password is not None
            and len(http_auth_password) > 128
        ):
            raise ValueError(
                "Invalid value for `http_auth_password`, length must be less than or equal to `128`"
            )
        if (
            self._configuration.client_side_validation
            and http_auth_password is not None
            and len(http_auth_password) < 0
        ):
            raise ValueError(
                "Invalid value for `http_auth_password`, length must be greater than or equal to `0`"
            )

        self._http_auth_password = http_auth_password

    @property
    def http_auth_domain(self):
        # type: () -> str
        """Gets the http_auth_domain of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The http_auth_domain of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._http_auth_domain

    @http_auth_domain.setter
    def http_auth_domain(self, http_auth_domain):
        """Sets the http_auth_domain of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param http_auth_domain: The http_auth_domain of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and http_auth_domain is not None
            and len(http_auth_domain) > 256
        ):
            raise ValueError(
                "Invalid value for `http_auth_domain`, length must be less than or equal to `256`"
            )
        if (
            self._configuration.client_side_validation
            and http_auth_domain is not None
            and len(http_auth_domain) < 0
        ):
            raise ValueError(
                "Invalid value for `http_auth_domain`, length must be greater than or equal to `0`"
            )

        self._http_auth_domain = http_auth_domain

    @property
    def otp_secret_key(self):
        # type: () -> str
        """Gets the otp_secret_key of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The otp_secret_key of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._otp_secret_key

    @otp_secret_key.setter
    def otp_secret_key(self, otp_secret_key):
        """Sets the otp_secret_key of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param otp_secret_key: The otp_secret_key of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and otp_secret_key is not None
            and len(otp_secret_key) > 256
        ):
            raise ValueError(
                "Invalid value for `otp_secret_key`, length must be less than or equal to `256`"
            )
        if (
            self._configuration.client_side_validation
            and otp_secret_key is not None
            and len(otp_secret_key) < 0
        ):
            raise ValueError(
                "Invalid value for `otp_secret_key`, length must be greater than or equal to `0`"
            )

        self._otp_secret_key = otp_secret_key

    @property
    def otp_length(self):
        # type: () -> int
        """Gets the otp_length of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The otp_length of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._otp_length

    @otp_length.setter
    def otp_length(self, otp_length):
        """Sets the otp_length of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param otp_length: The otp_length of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and otp_length is not None
            and otp_length > 100
        ):
            raise ValueError(
                "Invalid value for `otp_length`, must be a value less than or equal to `100`"
            )
        if self._configuration.client_side_validation and otp_length is not None and otp_length < 6:
            raise ValueError(
                "Invalid value for `otp_length`, must be a value greater than or equal to `6`"
            )

        self._otp_length = otp_length

    @property
    def otp_hash_type(self):
        # type: () -> str
        """Gets the otp_hash_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The otp_hash_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._otp_hash_type

    @otp_hash_type.setter
    def otp_hash_type(self, otp_hash_type):
        """Sets the otp_hash_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param otp_hash_type: The otp_hash_type of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        allowed_values = ["Sha1", "None", "Sha256", "Sha512"]
        if self._configuration.client_side_validation and otp_hash_type not in allowed_values:
            raise ValueError(
                "Invalid value for `otp_hash_type` ({}), must be one of {}".format(
                    otp_hash_type, allowed_values
                )
            )

        self._otp_hash_type = otp_hash_type

    @property
    def otp_time_step(self):
        # type: () -> int
        """Gets the otp_time_step of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The otp_time_step of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._otp_time_step

    @otp_time_step.setter
    def otp_time_step(self, otp_time_step):
        """Sets the otp_time_step of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param otp_time_step: The otp_time_step of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and otp_time_step is not None
            and otp_time_step > 300
        ):
            raise ValueError(
                "Invalid value for `otp_time_step`, must be a value less than or equal to `300`"
            )
        if (
            self._configuration.client_side_validation
            and otp_time_step is not None
            and otp_time_step < 1
        ):
            raise ValueError(
                "Invalid value for `otp_time_step`, must be a value greater than or equal to `1`"
            )

        self._otp_time_step = otp_time_step

    @property
    def otp_http_parameters(self):
        # type: () -> str
        """Gets the otp_http_parameters of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The otp_http_parameters of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._otp_http_parameters

    @otp_http_parameters.setter
    def otp_http_parameters(self, otp_http_parameters):
        """Sets the otp_http_parameters of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param otp_http_parameters: The otp_http_parameters of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and otp_http_parameters is not None
            and len(otp_http_parameters) > 256
        ):
            raise ValueError(
                "Invalid value for `otp_http_parameters`, length must be less than or equal to `256`"
            )
        if (
            self._configuration.client_side_validation
            and otp_http_parameters is not None
            and len(otp_http_parameters) < 0
        ):
            raise ValueError(
                "Invalid value for `otp_http_parameters`, length must be greater than or equal to `0`"
            )

        self._otp_http_parameters = otp_http_parameters

    @property
    def thread_num(self):
        # type: () -> int
        """Gets the thread_num of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The thread_num of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._thread_num

    @thread_num.setter
    def thread_num(self, thread_num):
        """Sets the thread_num of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param thread_num: The thread_num of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and thread_num is not None
            and thread_num > 20
        ):
            raise ValueError(
                "Invalid value for `thread_num`, must be a value less than or equal to `20`"
            )
        if self._configuration.client_side_validation and thread_num is not None and thread_num < 1:
            raise ValueError(
                "Invalid value for `thread_num`, must be a value greater than or equal to `1`"
            )

        self._thread_num = thread_num

    @property
    def connection_timeout(self):
        # type: () -> int
        """Gets the connection_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The connection_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._connection_timeout

    @connection_timeout.setter
    def connection_timeout(self, connection_timeout):
        """Sets the connection_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param connection_timeout: The connection_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and connection_timeout is not None
            and connection_timeout > 180
        ):
            raise ValueError(
                "Invalid value for `connection_timeout`, must be a value less than or equal to `180`"
            )
        if (
            self._configuration.client_side_validation
            and connection_timeout is not None
            and connection_timeout < 1
        ):
            raise ValueError(
                "Invalid value for `connection_timeout`, must be a value greater than or equal to `1`"
            )

        self._connection_timeout = connection_timeout

    @property
    def test_policy(self):
        # type: () -> str
        """Gets the test_policy of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The test_policy of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._test_policy

    @test_policy.setter
    def test_policy(self, test_policy):
        """Sets the test_policy of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param test_policy: The test_policy of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and test_policy is not None
            and len(test_policy) > 1024
        ):
            raise ValueError(
                "Invalid value for `test_policy`, length must be less than or equal to `1024`"
            )
        if (
            self._configuration.client_side_validation
            and test_policy is not None
            and len(test_policy) < 0
        ):
            raise ValueError(
                "Invalid value for `test_policy`, length must be greater than or equal to `0`"
            )

        self._test_policy = test_policy

    @property
    def test_optimization_level(self):
        # type: () -> str
        """Gets the test_optimization_level of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The test_optimization_level of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._test_optimization_level

    @test_optimization_level.setter
    def test_optimization_level(self, test_optimization_level):
        """Sets the test_optimization_level of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param test_optimization_level: The test_optimization_level of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        allowed_values = ["NoOptimization", "Fast", "Faster", "Fastest"]
        if (
            self._configuration.client_side_validation
            and test_optimization_level not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `test_optimization_level` ({}), must be one of {}".format(
                    test_optimization_level, allowed_values
                )
            )

        self._test_optimization_level = test_optimization_level

    @property
    def use_automatic_timeout(self):
        # type: () -> bool
        """Gets the use_automatic_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The use_automatic_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._use_automatic_timeout

    @use_automatic_timeout.setter
    def use_automatic_timeout(self, use_automatic_timeout):
        """Sets the use_automatic_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param use_automatic_timeout: The use_automatic_timeout of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._use_automatic_timeout = use_automatic_timeout

    @property
    def max_requests_in(self):
        # type: () -> int
        """Gets the max_requests_in of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The max_requests_in of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._max_requests_in

    @max_requests_in.setter
    def max_requests_in(self, max_requests_in):
        """Sets the max_requests_in of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param max_requests_in: The max_requests_in of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and max_requests_in is not None
            and max_requests_in > 1000000
        ):
            raise ValueError(
                "Invalid value for `max_requests_in`, must be a value less than or equal to `1000000`"
            )
        if (
            self._configuration.client_side_validation
            and max_requests_in is not None
            and max_requests_in < 1
        ):
            raise ValueError(
                "Invalid value for `max_requests_in`, must be a value greater than or equal to `1`"
            )

        self._max_requests_in = max_requests_in

    @property
    def max_requests_time_frame(self):
        # type: () -> int
        """Gets the max_requests_time_frame of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The max_requests_time_frame of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: int
        """
        return self._max_requests_time_frame

    @max_requests_time_frame.setter
    def max_requests_time_frame(self, max_requests_time_frame):
        """Sets the max_requests_time_frame of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param max_requests_time_frame: The max_requests_time_frame of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: int
        """
        if (
            self._configuration.client_side_validation
            and max_requests_time_frame is not None
            and max_requests_time_frame > 30000
        ):
            raise ValueError(
                "Invalid value for `max_requests_time_frame`, must be a value less than or equal to `30000`"
            )
        if (
            self._configuration.client_side_validation
            and max_requests_time_frame is not None
            and max_requests_time_frame < 1
        ):
            raise ValueError(
                "Invalid value for `max_requests_time_frame`, must be a value greater than or equal to `1`"
            )

        self._max_requests_time_frame = max_requests_time_frame

    @property
    def should_scan_below_this_directory(self):
        # type: () -> bool
        """Gets the should_scan_below_this_directory of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The should_scan_below_this_directory of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._should_scan_below_this_directory

    @should_scan_below_this_directory.setter
    def should_scan_below_this_directory(self, should_scan_below_this_directory):
        """Sets the should_scan_below_this_directory of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param should_scan_below_this_directory: The should_scan_below_this_directory of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._should_scan_below_this_directory = should_scan_below_this_directory

    @property
    def allowed_domains(self):
        # type: () -> list[str]
        """Gets the allowed_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The allowed_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: list[str]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """Sets the allowed_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param allowed_domains: The allowed_domains of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: list[str]
        """

        self._allowed_domains = allowed_domains

    @property
    def use_case_sensitive_paths(self):
        # type: () -> bool
        """Gets the use_case_sensitive_paths of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The use_case_sensitive_paths of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._use_case_sensitive_paths

    @use_case_sensitive_paths.setter
    def use_case_sensitive_paths(self, use_case_sensitive_paths):
        """Sets the use_case_sensitive_paths of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param use_case_sensitive_paths: The use_case_sensitive_paths of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._use_case_sensitive_paths = use_case_sensitive_paths

    @property
    def only_full_results(self):
        # type: () -> bool
        """Gets the only_full_results of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The only_full_results of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._only_full_results

    @only_full_results.setter
    def only_full_results(self, only_full_results):
        """Sets the only_full_results of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param only_full_results: The only_full_results of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._only_full_results = only_full_results

    @property
    def login_sequence_file_id(self):
        # type: () -> str
        """Gets the login_sequence_file_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The login_sequence_file_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._login_sequence_file_id

    @login_sequence_file_id.setter
    def login_sequence_file_id(self, login_sequence_file_id):
        """Sets the login_sequence_file_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param login_sequence_file_id: The login_sequence_file_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """

        self._login_sequence_file_id = login_sequence_file_id

    @property
    def fully_automatic(self):
        # type: () -> bool
        """Gets the fully_automatic of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The fully_automatic of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._fully_automatic

    @fully_automatic.setter
    def fully_automatic(self, fully_automatic):
        """Sets the fully_automatic of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param fully_automatic: The fully_automatic of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._fully_automatic = fully_automatic

    @property
    def scan_name(self):
        # type: () -> str
        """Gets the scan_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The scan_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._scan_name

    @scan_name.setter
    def scan_name(self, scan_name):
        """Sets the scan_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param scan_name: The scan_name of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if self._configuration.client_side_validation and scan_name is None:
            raise ValueError("Invalid value for `scan_name`, must not be `None`")
        if (
            self._configuration.client_side_validation
            and scan_name is not None
            and len(scan_name) > 1024
        ):
            raise ValueError(
                "Invalid value for `scan_name`, length must be less than or equal to `1024`"
            )
        if (
            self._configuration.client_side_validation
            and scan_name is not None
            and len(scan_name) < 1
        ):
            raise ValueError(
                "Invalid value for `scan_name`, length must be greater than or equal to `1`"
            )

        self._scan_name = scan_name

    @property
    def enable_mail_notification(self):
        # type: () -> bool
        """Gets the enable_mail_notification of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The enable_mail_notification of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._enable_mail_notification

    @enable_mail_notification.setter
    def enable_mail_notification(self, enable_mail_notification):
        """Sets the enable_mail_notification of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param enable_mail_notification: The enable_mail_notification of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._enable_mail_notification = enable_mail_notification

    @property
    def locale(self):
        # type: () -> str
        """Gets the locale of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The locale of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param locale: The locale of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if self._configuration.client_side_validation and locale is not None and len(locale) > 10:
            raise ValueError(
                "Invalid value for `locale`, length must be less than or equal to `10`"
            )
        if self._configuration.client_side_validation and locale is not None and len(locale) < 0:
            raise ValueError(
                "Invalid value for `locale`, length must be greater than or equal to `0`"
            )

        self._locale = locale

    @property
    def app_id(self):
        # type: () -> str
        """Gets the app_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The app_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param app_id: The app_id of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if self._configuration.client_side_validation and app_id is None:
            raise ValueError("Invalid value for `app_id`, must not be `None`")

        self._app_id = app_id

    @property
    def execute(self):
        # type: () -> bool
        """Gets the execute of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The execute of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._execute

    @execute.setter
    def execute(self, execute):
        """Sets the execute of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param execute: The execute of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._execute = execute

    @property
    def personal(self):
        # type: () -> bool
        """Gets the personal of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The personal of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: bool
        """
        return self._personal

    @personal.setter
    def personal(self, personal):
        """Sets the personal of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param personal: The personal of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: bool
        """

        self._personal = personal

    @property
    def comment(self):
        # type: () -> str
        """Gets the comment of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :return: The comment of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UserSiteCommonModelsNewDynamicAnalyzerScan.


        :param comment: The comment of this UserSiteCommonModelsNewDynamicAnalyzerScan.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and comment is not None
            and len(comment) > 2048
        ):
            raise ValueError(
                "Invalid value for `comment`, length must be less than or equal to `2048`"
            )
        if self._configuration.client_side_validation and comment is not None and len(comment) < 0:
            raise ValueError(
                "Invalid value for `comment`, length must be greater than or equal to `0`"
            )

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsNewDynamicAnalyzerScan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsNewDynamicAnalyzerScan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsNewDynamicAnalyzerScan):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class AppScanSaaSModelsV2DynamicAnalyzerScanExecution:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "starting_url": "str",
        "login_user": "str",
        "n_visited_pages": "int",
        "n_unvisited_pages": "int",
        "n_tested_entities": "int",
        "n_entities": "int",
        "n_requests_sent": "int",
        "scan_log_url": "str",
        "id": "str",
        "scan_id": "str",
        "created_at": "datetime",
        "executed_at": "datetime",
        "scan_end_time": "datetime",
        "execution_duration_sec": "int",
        "user_message": "str",
        "predefined_message_key": "str",
        "status": "str",
        "n_issues_found": "int",
        "result": "str",
        "read_status": "str",
        "progress": "int",
        "n_critical_issues": "int",
        "n_high_issues": "int",
        "n_medium_issues": "int",
        "n_low_issues": "int",
        "n_info_issues": "int",
        "n_open_source_licenses": "int",
        "n_open_source_packages": "int",
        "n_new_app_issues": "int",
        "n_new_app_critical_issues": "int",
        "n_new_app_high_issues": "int",
        "n_new_app_medium_issues": "int",
        "n_new_app_low_issues": "int",
        "n_new_app_info_issues": "int",
        "available_reports": "list[str]",
        "execution_progress": "str",
        "include_custom_user_message": "bool",
        "has_logs": "bool",
        "file_name": "str",
        "created_by": "UserSiteCommonModelsBasicUserInfo",
        "is_scan_file_available": "bool",
        "comment": "str",
        "enablement_message": "str",
        "handled_by_scan_enabler": "bool",
        "is_partial": "bool",
        "queued_duration_sec": "int",
    }

    attribute_map = {
        "starting_url": "StartingUrl",
        "login_user": "LoginUser",
        "n_visited_pages": "NVisitedPages",
        "n_unvisited_pages": "NUnvisitedPages",
        "n_tested_entities": "NTestedEntities",
        "n_entities": "NEntities",
        "n_requests_sent": "NRequestsSent",
        "scan_log_url": "ScanLogUrl",
        "id": "Id",
        "scan_id": "ScanId",
        "created_at": "CreatedAt",
        "executed_at": "ExecutedAt",
        "scan_end_time": "ScanEndTime",
        "execution_duration_sec": "ExecutionDurationSec",
        "user_message": "UserMessage",
        "predefined_message_key": "PredefinedMessageKey",
        "status": "Status",
        "n_issues_found": "NIssuesFound",
        "result": "Result",
        "read_status": "ReadStatus",
        "progress": "Progress",
        "n_critical_issues": "NCriticalIssues",
        "n_high_issues": "NHighIssues",
        "n_medium_issues": "NMediumIssues",
        "n_low_issues": "NLowIssues",
        "n_info_issues": "NInfoIssues",
        "n_open_source_licenses": "NOpenSourceLicenses",
        "n_open_source_packages": "NOpenSourcePackages",
        "n_new_app_issues": "NNewAppIssues",
        "n_new_app_critical_issues": "NNewAppCriticalIssues",
        "n_new_app_high_issues": "NNewAppHighIssues",
        "n_new_app_medium_issues": "NNewAppMediumIssues",
        "n_new_app_low_issues": "NNewAppLowIssues",
        "n_new_app_info_issues": "NNewAppInfoIssues",
        "available_reports": "AvailableReports",
        "execution_progress": "ExecutionProgress",
        "include_custom_user_message": "IncludeCustomUserMessage",
        "has_logs": "HasLogs",
        "file_name": "FileName",
        "created_by": "CreatedBy",
        "is_scan_file_available": "IsScanFileAvailable",
        "comment": "Comment",
        "enablement_message": "EnablementMessage",
        "handled_by_scan_enabler": "HandledByScanEnabler",
        "is_partial": "IsPartial",
        "queued_duration_sec": "QueuedDurationSec",
    }

    def __init__(
        self,
        starting_url=None,
        login_user=None,
        n_visited_pages=None,
        n_unvisited_pages=None,
        n_tested_entities=None,
        n_entities=None,
        n_requests_sent=None,
        scan_log_url=None,
        id=None,
        scan_id=None,
        created_at=None,
        executed_at=None,
        scan_end_time=None,
        execution_duration_sec=None,
        user_message=None,
        predefined_message_key=None,
        status=None,
        n_issues_found=None,
        result=None,
        read_status=None,
        progress=None,
        n_critical_issues=None,
        n_high_issues=None,
        n_medium_issues=None,
        n_low_issues=None,
        n_info_issues=None,
        n_open_source_licenses=None,
        n_open_source_packages=None,
        n_new_app_issues=None,
        n_new_app_critical_issues=None,
        n_new_app_high_issues=None,
        n_new_app_medium_issues=None,
        n_new_app_low_issues=None,
        n_new_app_info_issues=None,
        available_reports=None,
        execution_progress=None,
        include_custom_user_message=None,
        has_logs=None,
        file_name=None,
        created_by=None,
        is_scan_file_available=None,
        comment=None,
        enablement_message=None,
        handled_by_scan_enabler=None,
        is_partial=None,
        queued_duration_sec=None,
        _configuration=None,
    ):
        """AppScanSaaSModelsV2DynamicAnalyzerScanExecution - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._starting_url = None
        self._login_user = None
        self._n_visited_pages = None
        self._n_unvisited_pages = None
        self._n_tested_entities = None
        self._n_entities = None
        self._n_requests_sent = None
        self._scan_log_url = None
        self._id = None
        self._scan_id = None
        self._created_at = None
        self._executed_at = None
        self._scan_end_time = None
        self._execution_duration_sec = None
        self._user_message = None
        self._predefined_message_key = None
        self._status = None
        self._n_issues_found = None
        self._result = None
        self._read_status = None
        self._progress = None
        self._n_critical_issues = None
        self._n_high_issues = None
        self._n_medium_issues = None
        self._n_low_issues = None
        self._n_info_issues = None
        self._n_open_source_licenses = None
        self._n_open_source_packages = None
        self._n_new_app_issues = None
        self._n_new_app_critical_issues = None
        self._n_new_app_high_issues = None
        self._n_new_app_medium_issues = None
        self._n_new_app_low_issues = None
        self._n_new_app_info_issues = None
        self._available_reports = None
        self._execution_progress = None
        self._include_custom_user_message = None
        self._has_logs = None
        self._file_name = None
        self._created_by = None
        self._is_scan_file_available = None
        self._comment = None
        self._enablement_message = None
        self._handled_by_scan_enabler = None
        self._is_partial = None
        self._queued_duration_sec = None
        self.discriminator = None

        if starting_url is not None:
            self.starting_url = starting_url
        if login_user is not None:
            self.login_user = login_user
        if n_visited_pages is not None:
            self.n_visited_pages = n_visited_pages
        if n_unvisited_pages is not None:
            self.n_unvisited_pages = n_unvisited_pages
        if n_tested_entities is not None:
            self.n_tested_entities = n_tested_entities
        if n_entities is not None:
            self.n_entities = n_entities
        if n_requests_sent is not None:
            self.n_requests_sent = n_requests_sent
        if scan_log_url is not None:
            self.scan_log_url = scan_log_url
        if id is not None:
            self.id = id
        if scan_id is not None:
            self.scan_id = scan_id
        if created_at is not None:
            self.created_at = created_at
        if executed_at is not None:
            self.executed_at = executed_at
        if scan_end_time is not None:
            self.scan_end_time = scan_end_time
        if execution_duration_sec is not None:
            self.execution_duration_sec = execution_duration_sec
        if user_message is not None:
            self.user_message = user_message
        if predefined_message_key is not None:
            self.predefined_message_key = predefined_message_key
        if status is not None:
            self.status = status
        if n_issues_found is not None:
            self.n_issues_found = n_issues_found
        if result is not None:
            self.result = result
        if read_status is not None:
            self.read_status = read_status
        if progress is not None:
            self.progress = progress
        if n_critical_issues is not None:
            self.n_critical_issues = n_critical_issues
        if n_high_issues is not None:
            self.n_high_issues = n_high_issues
        if n_medium_issues is not None:
            self.n_medium_issues = n_medium_issues
        if n_low_issues is not None:
            self.n_low_issues = n_low_issues
        if n_info_issues is not None:
            self.n_info_issues = n_info_issues
        if n_open_source_licenses is not None:
            self.n_open_source_licenses = n_open_source_licenses
        if n_open_source_packages is not None:
            self.n_open_source_packages = n_open_source_packages
        if n_new_app_issues is not None:
            self.n_new_app_issues = n_new_app_issues
        if n_new_app_critical_issues is not None:
            self.n_new_app_critical_issues = n_new_app_critical_issues
        if n_new_app_high_issues is not None:
            self.n_new_app_high_issues = n_new_app_high_issues
        if n_new_app_medium_issues is not None:
            self.n_new_app_medium_issues = n_new_app_medium_issues
        if n_new_app_low_issues is not None:
            self.n_new_app_low_issues = n_new_app_low_issues
        if n_new_app_info_issues is not None:
            self.n_new_app_info_issues = n_new_app_info_issues
        if available_reports is not None:
            self.available_reports = available_reports
        if execution_progress is not None:
            self.execution_progress = execution_progress
        if include_custom_user_message is not None:
            self.include_custom_user_message = include_custom_user_message
        if has_logs is not None:
            self.has_logs = has_logs
        if file_name is not None:
            self.file_name = file_name
        if created_by is not None:
            self.created_by = created_by
        if is_scan_file_available is not None:
            self.is_scan_file_available = is_scan_file_available
        if comment is not None:
            self.comment = comment
        if enablement_message is not None:
            self.enablement_message = enablement_message
        if handled_by_scan_enabler is not None:
            self.handled_by_scan_enabler = handled_by_scan_enabler
        if is_partial is not None:
            self.is_partial = is_partial
        if queued_duration_sec is not None:
            self.queued_duration_sec = queued_duration_sec

    @property
    def starting_url(self):
        # type: () -> str
        """Gets the starting_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The starting_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._starting_url

    @starting_url.setter
    def starting_url(self, starting_url):
        """Sets the starting_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param starting_url: The starting_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._starting_url = starting_url

    @property
    def login_user(self):
        # type: () -> str
        """Gets the login_user of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The login_user of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._login_user

    @login_user.setter
    def login_user(self, login_user):
        """Sets the login_user of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param login_user: The login_user of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._login_user = login_user

    @property
    def n_visited_pages(self):
        # type: () -> int
        """Gets the n_visited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_visited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_visited_pages

    @n_visited_pages.setter
    def n_visited_pages(self, n_visited_pages):
        """Sets the n_visited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_visited_pages: The n_visited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_visited_pages = n_visited_pages

    @property
    def n_unvisited_pages(self):
        # type: () -> int
        """Gets the n_unvisited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_unvisited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_unvisited_pages

    @n_unvisited_pages.setter
    def n_unvisited_pages(self, n_unvisited_pages):
        """Sets the n_unvisited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_unvisited_pages: The n_unvisited_pages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_unvisited_pages = n_unvisited_pages

    @property
    def n_tested_entities(self):
        # type: () -> int
        """Gets the n_tested_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_tested_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_tested_entities

    @n_tested_entities.setter
    def n_tested_entities(self, n_tested_entities):
        """Sets the n_tested_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_tested_entities: The n_tested_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_tested_entities = n_tested_entities

    @property
    def n_entities(self):
        # type: () -> int
        """Gets the n_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_entities

    @n_entities.setter
    def n_entities(self, n_entities):
        """Sets the n_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_entities: The n_entities of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_entities = n_entities

    @property
    def n_requests_sent(self):
        # type: () -> int
        """Gets the n_requests_sent of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_requests_sent of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_requests_sent

    @n_requests_sent.setter
    def n_requests_sent(self, n_requests_sent):
        """Sets the n_requests_sent of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_requests_sent: The n_requests_sent of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_requests_sent = n_requests_sent

    @property
    def scan_log_url(self):
        # type: () -> str
        """Gets the scan_log_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The scan_log_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._scan_log_url

    @scan_log_url.setter
    def scan_log_url(self, scan_log_url):
        """Sets the scan_log_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param scan_log_url: The scan_log_url of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._scan_log_url = scan_log_url

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param id: The id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._id = id

    @property
    def scan_id(self):
        # type: () -> str
        """Gets the scan_id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The scan_id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._scan_id

    @scan_id.setter
    def scan_id(self, scan_id):
        """Sets the scan_id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param scan_id: The scan_id of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._scan_id = scan_id

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The created_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param created_at: The created_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def executed_at(self):
        # type: () -> datetime
        """Gets the executed_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The executed_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: datetime
        """
        return self._executed_at

    @executed_at.setter
    def executed_at(self, executed_at):
        """Sets the executed_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param executed_at: The executed_at of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: datetime
        """

        self._executed_at = executed_at

    @property
    def scan_end_time(self):
        # type: () -> datetime
        """Gets the scan_end_time of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The scan_end_time of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: datetime
        """
        return self._scan_end_time

    @scan_end_time.setter
    def scan_end_time(self, scan_end_time):
        """Sets the scan_end_time of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param scan_end_time: The scan_end_time of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: datetime
        """

        self._scan_end_time = scan_end_time

    @property
    def execution_duration_sec(self):
        # type: () -> int
        """Gets the execution_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The execution_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._execution_duration_sec

    @execution_duration_sec.setter
    def execution_duration_sec(self, execution_duration_sec):
        """Sets the execution_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param execution_duration_sec: The execution_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._execution_duration_sec = execution_duration_sec

    @property
    def user_message(self):
        # type: () -> str
        """Gets the user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._user_message

    @user_message.setter
    def user_message(self, user_message):
        """Sets the user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param user_message: The user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._user_message = user_message

    @property
    def predefined_message_key(self):
        # type: () -> str
        """Gets the predefined_message_key of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The predefined_message_key of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._predefined_message_key

    @predefined_message_key.setter
    def predefined_message_key(self, predefined_message_key):
        """Sets the predefined_message_key of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param predefined_message_key: The predefined_message_key of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._predefined_message_key = predefined_message_key

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param status: The status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """
        allowed_values = [
            "Running",
            "Stopping",
            "Pausing",
            "InQueue",
            "Paused",
            "Ready",
            "Failed",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def n_issues_found(self):
        # type: () -> int
        """Gets the n_issues_found of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_issues_found of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_issues_found

    @n_issues_found.setter
    def n_issues_found(self, n_issues_found):
        """Sets the n_issues_found of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_issues_found: The n_issues_found of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_issues_found = n_issues_found

    @property
    def result(self):
        # type: () -> str
        """Gets the result of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The result of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param result: The result of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """
        allowed_values = [
            "None",
            "NoIssues",
            "Informational",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and result not in allowed_values:
            raise ValueError(
                f"Invalid value for `result` ({result}), must be one of {allowed_values}"
            )

        self._result = result

    @property
    def read_status(self):
        # type: () -> str
        """Gets the read_status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The read_status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._read_status

    @read_status.setter
    def read_status(self, read_status):
        """Sets the read_status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param read_status: The read_status of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """
        allowed_values = ["None", "Unread", "Read"]
        if self._configuration.client_side_validation and read_status not in allowed_values:
            raise ValueError(
                "Invalid value for `read_status` ({}), must be one of {}".format(
                    read_status, allowed_values
                )
            )

        self._read_status = read_status

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param progress: The progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._progress = progress

    @property
    def n_critical_issues(self):
        # type: () -> int
        """Gets the n_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_critical_issues

    @n_critical_issues.setter
    def n_critical_issues(self, n_critical_issues):
        """Sets the n_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_critical_issues: The n_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_critical_issues = n_critical_issues

    @property
    def n_high_issues(self):
        # type: () -> int
        """Gets the n_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_high_issues

    @n_high_issues.setter
    def n_high_issues(self, n_high_issues):
        """Sets the n_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_high_issues: The n_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_high_issues = n_high_issues

    @property
    def n_medium_issues(self):
        # type: () -> int
        """Gets the n_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_medium_issues

    @n_medium_issues.setter
    def n_medium_issues(self, n_medium_issues):
        """Sets the n_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_medium_issues: The n_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_medium_issues = n_medium_issues

    @property
    def n_low_issues(self):
        # type: () -> int
        """Gets the n_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_low_issues

    @n_low_issues.setter
    def n_low_issues(self, n_low_issues):
        """Sets the n_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_low_issues: The n_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_low_issues = n_low_issues

    @property
    def n_info_issues(self):
        # type: () -> int
        """Gets the n_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_info_issues

    @n_info_issues.setter
    def n_info_issues(self, n_info_issues):
        """Sets the n_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_info_issues: The n_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_info_issues = n_info_issues

    @property
    def n_open_source_licenses(self):
        # type: () -> int
        """Gets the n_open_source_licenses of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_open_source_licenses of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_open_source_licenses

    @n_open_source_licenses.setter
    def n_open_source_licenses(self, n_open_source_licenses):
        """Sets the n_open_source_licenses of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_open_source_licenses: The n_open_source_licenses of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_open_source_licenses = n_open_source_licenses

    @property
    def n_open_source_packages(self):
        # type: () -> int
        """Gets the n_open_source_packages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_open_source_packages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_open_source_packages

    @n_open_source_packages.setter
    def n_open_source_packages(self, n_open_source_packages):
        """Sets the n_open_source_packages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_open_source_packages: The n_open_source_packages of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_open_source_packages = n_open_source_packages

    @property
    def n_new_app_issues(self):
        # type: () -> int
        """Gets the n_new_app_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_issues

    @n_new_app_issues.setter
    def n_new_app_issues(self, n_new_app_issues):
        """Sets the n_new_app_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_issues: The n_new_app_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_issues = n_new_app_issues

    @property
    def n_new_app_critical_issues(self):
        # type: () -> int
        """Gets the n_new_app_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_critical_issues

    @n_new_app_critical_issues.setter
    def n_new_app_critical_issues(self, n_new_app_critical_issues):
        """Sets the n_new_app_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_critical_issues: The n_new_app_critical_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_critical_issues = n_new_app_critical_issues

    @property
    def n_new_app_high_issues(self):
        # type: () -> int
        """Gets the n_new_app_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_high_issues

    @n_new_app_high_issues.setter
    def n_new_app_high_issues(self, n_new_app_high_issues):
        """Sets the n_new_app_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_high_issues: The n_new_app_high_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_high_issues = n_new_app_high_issues

    @property
    def n_new_app_medium_issues(self):
        # type: () -> int
        """Gets the n_new_app_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_medium_issues

    @n_new_app_medium_issues.setter
    def n_new_app_medium_issues(self, n_new_app_medium_issues):
        """Sets the n_new_app_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_medium_issues: The n_new_app_medium_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_medium_issues = n_new_app_medium_issues

    @property
    def n_new_app_low_issues(self):
        # type: () -> int
        """Gets the n_new_app_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_low_issues

    @n_new_app_low_issues.setter
    def n_new_app_low_issues(self, n_new_app_low_issues):
        """Sets the n_new_app_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_low_issues: The n_new_app_low_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_low_issues = n_new_app_low_issues

    @property
    def n_new_app_info_issues(self):
        # type: () -> int
        """Gets the n_new_app_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The n_new_app_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._n_new_app_info_issues

    @n_new_app_info_issues.setter
    def n_new_app_info_issues(self, n_new_app_info_issues):
        """Sets the n_new_app_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param n_new_app_info_issues: The n_new_app_info_issues of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._n_new_app_info_issues = n_new_app_info_issues

    @property
    def available_reports(self):
        # type: () -> list[str]
        """Gets the available_reports of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The available_reports of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: list[str]
        """
        return self._available_reports

    @available_reports.setter
    def available_reports(self, available_reports):
        """Sets the available_reports of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param available_reports: The available_reports of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: list[str]
        """
        allowed_values = [
            "Xml",
            "Pdf",
            "Html",
            "CompliancePdf",
            "OwaspTop10Pdf",
            "Sans25Pdf",
            "RawXml",
            "Zip",
        ]
        if self._configuration.client_side_validation and not set(available_reports).issubset(
            set(allowed_values)
        ):
            raise ValueError(
                "Invalid values for `available_reports` [{}], must be a subset of [{}]".format(
                    ", ".join(map(str, set(available_reports) - set(allowed_values))),
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._available_reports = available_reports

    @property
    def execution_progress(self):
        # type: () -> str
        """Gets the execution_progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The execution_progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._execution_progress

    @execution_progress.setter
    def execution_progress(self, execution_progress):
        """Sets the execution_progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param execution_progress: The execution_progress of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """
        allowed_values = [
            "Pending",
            "Running",
            "UnderReview",
            "RunningManually",
            "Paused",
            "Completed",
        ]
        if self._configuration.client_side_validation and execution_progress not in allowed_values:
            raise ValueError(
                "Invalid value for `execution_progress` ({}), must be one of {}".format(
                    execution_progress, allowed_values
                )
            )

        self._execution_progress = execution_progress

    @property
    def include_custom_user_message(self):
        # type: () -> bool
        """Gets the include_custom_user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The include_custom_user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: bool
        """
        return self._include_custom_user_message

    @include_custom_user_message.setter
    def include_custom_user_message(self, include_custom_user_message):
        """Sets the include_custom_user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param include_custom_user_message: The include_custom_user_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: bool
        """

        self._include_custom_user_message = include_custom_user_message

    @property
    def has_logs(self):
        # type: () -> bool
        """Gets the has_logs of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The has_logs of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: bool
        """
        return self._has_logs

    @has_logs.setter
    def has_logs(self, has_logs):
        """Sets the has_logs of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param has_logs: The has_logs of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: bool
        """

        self._has_logs = has_logs

    @property
    def file_name(self):
        # type: () -> str
        """Gets the file_name of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The file_name of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param file_name: The file_name of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._file_name = file_name

    @property
    def created_by(self):
        # type: () -> UserSiteCommonModelsBasicUserInfo
        """Gets the created_by of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The created_by of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: UserSiteCommonModelsBasicUserInfo
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param created_by: The created_by of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: UserSiteCommonModelsBasicUserInfo
        """

        self._created_by = created_by

    @property
    def is_scan_file_available(self):
        # type: () -> bool
        """Gets the is_scan_file_available of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The is_scan_file_available of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: bool
        """
        return self._is_scan_file_available

    @is_scan_file_available.setter
    def is_scan_file_available(self, is_scan_file_available):
        """Sets the is_scan_file_available of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param is_scan_file_available: The is_scan_file_available of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: bool
        """

        self._is_scan_file_available = is_scan_file_available

    @property
    def comment(self):
        # type: () -> str
        """Gets the comment of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The comment of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param comment: The comment of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._comment = comment

    @property
    def enablement_message(self):
        # type: () -> str
        """Gets the enablement_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The enablement_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: str
        """
        return self._enablement_message

    @enablement_message.setter
    def enablement_message(self, enablement_message):
        """Sets the enablement_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param enablement_message: The enablement_message of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: str
        """

        self._enablement_message = enablement_message

    @property
    def handled_by_scan_enabler(self):
        # type: () -> bool
        """Gets the handled_by_scan_enabler of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The handled_by_scan_enabler of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: bool
        """
        return self._handled_by_scan_enabler

    @handled_by_scan_enabler.setter
    def handled_by_scan_enabler(self, handled_by_scan_enabler):
        """Sets the handled_by_scan_enabler of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param handled_by_scan_enabler: The handled_by_scan_enabler of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: bool
        """

        self._handled_by_scan_enabler = handled_by_scan_enabler

    @property
    def is_partial(self):
        # type: () -> bool
        """Gets the is_partial of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The is_partial of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: bool
        """
        return self._is_partial

    @is_partial.setter
    def is_partial(self, is_partial):
        """Sets the is_partial of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param is_partial: The is_partial of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: bool
        """

        self._is_partial = is_partial

    @property
    def queued_duration_sec(self):
        # type: () -> int
        """Gets the queued_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :return: The queued_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :rtype: int
        """
        return self._queued_duration_sec

    @queued_duration_sec.setter
    def queued_duration_sec(self, queued_duration_sec):
        """Sets the queued_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.


        :param queued_duration_sec: The queued_duration_sec of this AppScanSaaSModelsV2DynamicAnalyzerScanExecution.
        :type: int
        """

        self._queued_duration_sec = queued_duration_sec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AppScanSaaSModelsV2DynamicAnalyzerScanExecution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppScanSaaSModelsV2DynamicAnalyzerScanExecution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppScanSaaSModelsV2DynamicAnalyzerScanExecution):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsPresence:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "presence_name": "str",
        "key_expires_at": "datetime",
        "host_name": "str",
        "status": "str",
        "is_v2": "bool",
        "platform": "str",
    }

    attribute_map = {
        "id": "Id",
        "presence_name": "PresenceName",
        "key_expires_at": "KeyExpiresAt",
        "host_name": "HostName",
        "status": "Status",
        "is_v2": "IsV2",
        "platform": "Platform",
    }

    def __init__(
        self,
        id=None,
        presence_name=None,
        key_expires_at=None,
        host_name=None,
        status=None,
        is_v2=None,
        platform=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsPresence - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._presence_name = None
        self._key_expires_at = None
        self._host_name = None
        self._status = None
        self._is_v2 = None
        self._platform = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if presence_name is not None:
            self.presence_name = presence_name
        if key_expires_at is not None:
            self.key_expires_at = key_expires_at
        if host_name is not None:
            self.host_name = host_name
        if status is not None:
            self.status = status
        if is_v2 is not None:
            self.is_v2 = is_v2
        if platform is not None:
            self.platform = platform

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsPresence.


        :return: The id of this UserSiteCommonModelsPresence.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsPresence.


        :param id: The id of this UserSiteCommonModelsPresence.
        :type: str
        """

        self._id = id

    @property
    def presence_name(self):
        # type: () -> str
        """Gets the presence_name of this UserSiteCommonModelsPresence.


        :return: The presence_name of this UserSiteCommonModelsPresence.
        :rtype: str
        """
        return self._presence_name

    @presence_name.setter
    def presence_name(self, presence_name):
        """Sets the presence_name of this UserSiteCommonModelsPresence.


        :param presence_name: The presence_name of this UserSiteCommonModelsPresence.
        :type: str
        """

        self._presence_name = presence_name

    @property
    def key_expires_at(self):
        # type: () -> datetime
        """Gets the key_expires_at of this UserSiteCommonModelsPresence.


        :return: The key_expires_at of this UserSiteCommonModelsPresence.
        :rtype: datetime
        """
        return self._key_expires_at

    @key_expires_at.setter
    def key_expires_at(self, key_expires_at):
        """Sets the key_expires_at of this UserSiteCommonModelsPresence.


        :param key_expires_at: The key_expires_at of this UserSiteCommonModelsPresence.
        :type: datetime
        """

        self._key_expires_at = key_expires_at

    @property
    def host_name(self):
        # type: () -> str
        """Gets the host_name of this UserSiteCommonModelsPresence.


        :return: The host_name of this UserSiteCommonModelsPresence.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this UserSiteCommonModelsPresence.


        :param host_name: The host_name of this UserSiteCommonModelsPresence.
        :type: str
        """

        self._host_name = host_name

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this UserSiteCommonModelsPresence.


        :return: The status of this UserSiteCommonModelsPresence.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UserSiteCommonModelsPresence.


        :param status: The status of this UserSiteCommonModelsPresence.
        :type: str
        """
        allowed_values = [
            "Active",
            "NeverUsed",
            "KeyExpired",
            "KeyNeverUsed",
            "Inactive",
            "Disable",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def is_v2(self):
        # type: () -> bool
        """Gets the is_v2 of this UserSiteCommonModelsPresence.


        :return: The is_v2 of this UserSiteCommonModelsPresence.
        :rtype: bool
        """
        return self._is_v2

    @is_v2.setter
    def is_v2(self, is_v2):
        """Sets the is_v2 of this UserSiteCommonModelsPresence.


        :param is_v2: The is_v2 of this UserSiteCommonModelsPresence.
        :type: bool
        """

        self._is_v2 = is_v2

    @property
    def platform(self):
        # type: () -> str
        """Gets the platform of this UserSiteCommonModelsPresence.


        :return: The platform of this UserSiteCommonModelsPresence.
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this UserSiteCommonModelsPresence.


        :param platform: The platform of this UserSiteCommonModelsPresence.
        :type: str
        """

        self._platform = platform

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsPresence, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsPresence):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsPresence):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import re  # noqa: F401

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient


class ReportsApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def reports_article(self, issuetype, **kwargs):
        """Get Article

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article(issuetype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issuetype: Issue Type ID (required)
        :param str technology: Options: 'DAST', 'SAST', 'IAST', 'iOS', 'Android'. Not case sensitive.
        :param str api: (when available)
        :param str locale:
        :param str language: Programing Language
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_article_with_http_info(issuetype, **kwargs)
        else:
            (data) = self.reports_article_with_http_info(issuetype, **kwargs)
            return data

    def reports_article_with_http_info(self, issuetype, **kwargs):
        """Get Article

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article_with_http_info(issuetype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issuetype: Issue Type ID (required)
        :param str technology: Options: 'DAST', 'SAST', 'IAST', 'iOS', 'Android'. Not case sensitive.
        :param str api: (when available)
        :param str locale:
        :param str language: Programing Language
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "issuetype",
            "technology",
            "api",
            "locale",
            "language",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method reports_article" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issuetype' is set
        if self.api_client.client_side_validation and (
            "issuetype" not in params or params["issuetype"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issuetype` when calling `reports_article`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []
        if "issuetype" in params:
            query_params.append(("issuetype", params["issuetype"]))
        if "technology" in params:
            query_params.append(("technology", params["technology"]))
        if "api" in params:
            query_params.append(("api", params["api"]))
        if "locale" in params:
            query_params.append(("locale", params["locale"]))
        if "language" in params:
            query_params.append(("language", params["language"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            "/api/v2/Reports/Article",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_article_for_omnia_link(self, **kwargs):
        """Get Article according to embedded Omnia link format, using Issue type ID.  This API is for internal links of Omnia articles, which were returned by 'Article' API.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article_for_omnia_link(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Obsolete: Article ID. Use 'Issue type ID' instead
        :param str language: Programing Language
        :param str api: API vulnerability Name
        :param str nl: Translated Langauge
        :param str issuetype: Issue type ID
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_article_for_omnia_link_with_http_info(**kwargs)
        else:
            (data) = self.reports_article_for_omnia_link_with_http_info(**kwargs)
            return data

    def reports_article_for_omnia_link_with_http_info(self, **kwargs):
        """Get Article according to embedded Omnia link format, using Issue type ID.  This API is for internal links of Omnia articles, which were returned by 'Article' API.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article_for_omnia_link_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Obsolete: Article ID. Use 'Issue type ID' instead
        :param str language: Programing Language
        :param str api: API vulnerability Name
        :param str nl: Translated Langauge
        :param str issuetype: Issue type ID
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "language", "api", "nl", "issuetype"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_article_for_omnia_link" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "id" in params:
            query_params.append(("id", params["id"]))
        if "language" in params:
            query_params.append(("language", params["language"]))
        if "api" in params:
            query_params.append(("api", params["api"]))
        if "nl" in params:
            query_params.append(("nl", params["nl"]))
        if "issuetype" in params:
            query_params.append(("issuetype", params["issuetype"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            "/api/v2/Reports/ArticleForOmniaLink",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_article_for_open_source_component(self, component_name, **kwargs):
        """Get Article for Open Source Component

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article_for_open_source_component(component_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str component_name: Open-Source Component Name (required)
        :param str current_version: The component version in which the vulnerability was found.
        :param str fixed_version: The component version which contain a fix  to the vulnerability.
        :param str locale:
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_article_for_open_source_component_with_http_info(
                component_name, **kwargs
            )
        else:
            (data) = self.reports_article_for_open_source_component_with_http_info(
                component_name, **kwargs
            )
            return data

    def reports_article_for_open_source_component_with_http_info(self, component_name, **kwargs):
        """Get Article for Open Source Component

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_article_for_open_source_component_with_http_info(component_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str component_name: Open-Source Component Name (required)
        :param str current_version: The component version in which the vulnerability was found.
        :param str fixed_version: The component version which contain a fix  to the vulnerability.
        :param str locale:
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "component_name",
            "current_version",
            "fixed_version",
            "locale",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_article_for_open_source_component" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'component_name' is set
        if self.api_client.client_side_validation and (
            "component_name" not in params or params["component_name"] is None
        ):
            raise ValueError(
                "Missing the required parameter `component_name` when calling `reports_article_for_open_source_component`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []
        if "component_name" in params:
            query_params.append(("componentName", params["component_name"]))
        if "current_version" in params:
            query_params.append(("currentVersion", params["current_version"]))
        if "fixed_version" in params:
            query_params.append(("fixedVersion", params["fixed_version"]))
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            "/api/v2/Reports/ArticleForOpenSourceComponent",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_create_issues_report_by_scope_and_id(self, scope, id, config, **kwargs):
        """Create issues report for selected issues

        Full details of all issues in scope (JSON). <br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_issues_report_by_scope_and_id(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsIssuesReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_create_issues_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
        else:
            (data) = self.reports_create_issues_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
            return data

    def reports_create_issues_report_by_scope_and_id_with_http_info(
        self, scope, id, config, **kwargs
    ):
        """Create issues report for selected issues

        Full details of all issues in scope (JSON). <br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_issues_report_by_scope_and_id_with_http_info(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsIssuesReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["scope", "id", "config"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_create_issues_report_by_scope_and_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `reports_create_issues_report_by_scope_and_id`"
            )
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_create_issues_report_by_scope_and_id`"
            )
        # verify the required parameter 'config' is set
        if self.api_client.client_side_validation and (
            "config" not in params or params["config"] is None
        ):
            raise ValueError(
                "Missing the required parameter `config` when calling `reports_create_issues_report_by_scope_and_id`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "config" in params:
            body_params = params["config"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Reports/Issues/{scope}/{id}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsReportStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_create_license_report_by_scope_and_id(self, scope, id, config, **kwargs):
        """Create open source licenses report

        PDF or HTML format.<br />  OData filters can be applied.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_license_report_by_scope_and_id(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsLicenseReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_create_license_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
        else:
            (data) = self.reports_create_license_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
            return data

    def reports_create_license_report_by_scope_and_id_with_http_info(
        self, scope, id, config, **kwargs
    ):
        """Create open source licenses report

        PDF or HTML format.<br />  OData filters can be applied.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_license_report_by_scope_and_id_with_http_info(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsLicenseReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["scope", "id", "config"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_create_license_report_by_scope_and_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `reports_create_license_report_by_scope_and_id`"
            )
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_create_license_report_by_scope_and_id`"
            )
        # verify the required parameter 'config' is set
        if self.api_client.client_side_validation and (
            "config" not in params or params["config"] is None
        ):
            raise ValueError(
                "Missing the required parameter `config` when calling `reports_create_license_report_by_scope_and_id`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "config" in params:
            body_params = params["config"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Reports/Licenses/{scope}/{id}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsReportStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_create_regulation_report_by_scope_and_id(self, scope, id, config, **kwargs):
        """Create regulation report for selected issues

        PDF or HTML format.<br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_regulation_report_by_scope_and_id(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsRegulationReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_create_regulation_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
        else:
            (data) = self.reports_create_regulation_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
            return data

    def reports_create_regulation_report_by_scope_and_id_with_http_info(
        self, scope, id, config, **kwargs
    ):
        """Create regulation report for selected issues

        PDF or HTML format.<br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_regulation_report_by_scope_and_id_with_http_info(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsRegulationReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["scope", "id", "config"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_create_regulation_report_by_scope_and_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `reports_create_regulation_report_by_scope_and_id`"
            )
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_create_regulation_report_by_scope_and_id`"
            )
        # verify the required parameter 'config' is set
        if self.api_client.client_side_validation and (
            "config" not in params or params["config"] is None
        ):
            raise ValueError(
                "Missing the required parameter `config` when calling `reports_create_regulation_report_by_scope_and_id`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "config" in params:
            body_params = params["config"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Reports/Regulation/{scope}/{id}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsReportStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_create_security_report_by_scope_and_id(self, scope, id, config, **kwargs):
        """Create security report for selected issues

        PDF, HTML, XML or CSV format.<br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_security_report_by_scope_and_id(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsSecurityReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_create_security_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
        else:
            (data) = self.reports_create_security_report_by_scope_and_id_with_http_info(
                scope, id, config, **kwargs
            )
            return data

    def reports_create_security_report_by_scope_and_id_with_http_info(
        self, scope, id, config, **kwargs
    ):
        """Create security report for selected issues

        PDF, HTML, XML or CSV format.<br />  Policies and OData filters can be applied.<br />  If policies are applied, the report will contain only issues that are not compliant with these policies.  <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_create_security_report_by_scope_and_id_with_http_info(scope, id, config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope:  (required)
        :param str id: The entity id (required)
        :param UserSiteCommonModelsSecurityReportJob config:  (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["scope", "id", "config"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_create_security_report_by_scope_and_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `reports_create_security_report_by_scope_and_id`"
            )
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_create_security_report_by_scope_and_id`"
            )
        # verify the required parameter 'config' is set
        if self.api_client.client_side_validation and (
            "config" not in params or params["config"] is None
        ):
            raise ValueError(
                "Missing the required parameter `config` when calling `reports_create_security_report_by_scope_and_id`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "config" in params:
            body_params = params["config"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Reports/Security/{scope}/{id}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsReportStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_delete_report_by_id(self, id, **kwargs):
        """Delete a report

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_delete_report_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_delete_report_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.reports_delete_report_by_id_with_http_info(id, **kwargs)
            return data

    def reports_delete_report_by_id_with_http_info(self, id, **kwargs):
        """Delete a report

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_delete_report_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_delete_report_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_delete_report_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Reports/{id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_download_report_by_id(self, id, **kwargs):
        """Download a report

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_download_report_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_download_report_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.reports_download_report_by_id_with_http_info(id, **kwargs)
            return data

    def reports_download_report_by_id_with_http_info(self, id, **kwargs):
        """Download a report

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_download_report_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_download_report_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_download_report_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/octet-stream"])

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Reports/Download/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="file",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_get_report_job_by_id(self, id, **kwargs):
        """Get report status

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_get_report_job_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_get_report_job_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.reports_get_report_job_by_id_with_http_info(id, **kwargs)
            return data

    def reports_get_report_job_by_id_with_http_info(self, id, **kwargs):
        """Get report status

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_get_report_job_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Report job Id (required)
        :return: UserSiteCommonModelsReportStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_get_report_job_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `reports_get_report_job_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Reports/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsReportStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def reports_get_reports_jobs(self, **kwargs):
        """Get all available reports

        Includes all reports generated by the user in the last 24 hours.   <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_get_reports_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserSiteCommonModelsReportStatusModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.reports_get_reports_jobs_with_http_info(**kwargs)
        else:
            (data) = self.reports_get_reports_jobs_with_http_info(**kwargs)
            return data

    def reports_get_reports_jobs_with_http_info(self, **kwargs):
        """Get all available reports

        Includes all reports generated by the user in the last 24 hours.   <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reports_get_reports_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserSiteCommonModelsReportStatusModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reports_get_reports_jobs" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Reports",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsReportStatusModel]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



import csv
import pathlib
import shlex
from pprint import pprint
from tempfile import NamedTemporaryFile
from typing import TextIO

from cloup import (
    Choice,
    File,
    Path,
    argument,
    group,
    option,
    option_group,
    pass_context,
)
from cloup.constraints import require_one

from .asoc import Asoc, IssueLevels


@group(context_settings={"help_option_names": ["-h", "--help"]}, chain=True)
@option_group(
    "Application",
    option("-a", "--app-id", help="ASOC App ID", type=str),
    option("-an", "--app-name", help="ASOC App Name", type=str),
    constraint=require_one,
)
@option("-k", "--key-id", help="ASOC Key ID", type=str, required=True)
@option("-s", "--key-secret", help="ASOC Key Secret", type=str, required=True)
@option("-n", "--scan-name", help="Scan Name", type=str, default="main", show_default=True)
@option("--asset-group-id", help="Asset Group ID (defaults to Default Asset Group)", type=str)
@option(
    "-bi",
    "--business-impact",
    type=Choice(
        [
            "Unspecified",
            "Low",
            "Medium",
            "High",
            "Critical",
        ],
        case_sensitive=False,
    ),
    default="Low",
    show_default=True,
)
@pass_context
def cli(
    ctx,
    app_id,
    app_name,
    key_id,
    key_secret,
    scan_name,
    asset_group_id,
    business_impact,
):
    asoc = Asoc(
        key_id=key_id,
        key_secret=key_secret,
        app_id=app_id,
        scan_name=scan_name,
        app_name=app_name,
        asset_group_id=asset_group_id,
    )
    ctx.ensure_object(dict)
    ctx.obj["asoc"] = asoc


@cli.command()
@pass_context
@argument(
    "directory",
    type=Path(
        resolve_path=True,
        exists=True,
        file_okay=False,
        writable=True,
        path_type=pathlib.Path,
    ),
)
@option("-pa", "--packager-args", default="")
@option("--packager", default="appscan.sh", show_default=True)
@option("--comment", default="", show_default=True, help="Comment for new scan")
@option("--personal", is_flag=True, default=False, show_default=True, help="Personal scan")
def scan(ctx, directory, packager_args, packager, comment, personal):
    asoc: Asoc = ctx.obj["asoc"]
    asoc.create_scan(
        directory,
        packager=packager,
        extra_options=shlex.split(packager_args),
        comment=comment,
        personal=personal,
    )


@cli.command()
@pass_context
@option("-tm", "--timeout-minutes", default=60, show_default=True)
def wait(ctx, timeout_minutes: int = 60):
    asoc: Asoc = ctx.obj["asoc"]
    pprint(asoc.wait(timeout_minutes=timeout_minutes))


@cli.command()
@pass_context
@argument(
    "output_file",
    type=File("w", encoding="utf-8"),
    default="-",
)
def status_badge(ctx, output_file: TextIO):
    asoc: Asoc = ctx.obj["asoc"]
    asoc.write_status_badge(output_file)


@cli.command()
@pass_context
@argument(
    "output_file",
    type=File("w", encoding="utf-8"),
    default="-",
)
@option(
    "--cutoff-level",
    type=Choice([a.value for a in IssueLevels], case_sensitive=False),
    default="medium",
    help="count issues of this status and higher",
    show_default=True,
)
def num_issues_badge(ctx, output_file: TextIO, cutoff_level: str):
    asoc: Asoc = ctx.obj["asoc"]
    asoc.write_num_issues_badge(output_file, cutoff_level=cutoff_level)


@cli.command()
@pass_context
@argument(
    "directory",
    type=Path(
        resolve_path=True,
        exists=True,
        file_okay=False,
        writable=True,
        path_type=pathlib.Path,
    ),
    default=".",
)
def upload_external(ctx, directory):
    asoc: Asoc = ctx.obj["asoc"]

    new, fix, reopen, stay_open = asoc.filter_issues(directory.glob("*.json"))

    if fix:
        print(f"Marking {len(fix)} issues as fixed")
        asoc.change_issue_status_bulk([a.id for a in fix], "Fixed")
    if reopen:
        print(f"Marking {len(reopen)} issues as reopened")
        asoc.change_issue_status_bulk([a.id for a in reopen], "Reopened")
    if stay_open:
        print(f"Leaving {len(stay_open)} issues as still open")
        # print(asoc.change_issue_status_bulk([a.id for a in stay_open], "Open"))

    if new:
        print(f"Adding {len(new)} new issues")
        fieldnames = []
        for v in new:
            for k in v.keys():
                if k not in fieldnames:
                    fieldnames.append(k)
        with NamedTemporaryFile(suffix=".csv", mode="w+t", encoding="utf8") as csvfile:
            writer = csv.DictWriter(csvfile, fieldnames=fieldnames, dialect="excel")
            writer.writeheader()
            for v in new:
                writer.writerow(v)
            csvfile.flush()
            csvfile.seek(0)
            out = asoc.import_file(csvfile.name)
        print(out)
